==> ejc-bfyjerp-api-3.0.0-20250117.070815-104-sources.jar: com/ejianc/business/finance/vo/PayFlowVO.java <==
package com.ejianc.business.finance.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 出纳资金-出纳流水明细表
 * 
 * @author generator
 * 
 */
public class PayFlowVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date date; //日期
    private Integer parentOrgName; //区域
    private String payType; //收支类型
    private String onetypeName; //一级分类
    private String twoTypeName; //二级分类
    private String projectName; //项目名称
    private String memo; //摘要
    private String inMny; //收入
    private String outMny; //支出
    private String dfzhName; //对方账户
    private String gszhName; //公司账户

    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    public Integer getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(Integer parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public String getOnetypeName() {
        return onetypeName;
    }

    public void setOnetypeName(String onetypeName) {
        this.onetypeName = onetypeName;
    }

    public String getTwoTypeName() {
        return twoTypeName;
    }

    public void setTwoTypeName(String twoTypeName) {
        this.twoTypeName = twoTypeName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getInMny() {
        return inMny;
    }

    public void setInMny(String inMny) {
        this.inMny = inMny;
    }

    public String getOutMny() {
        return outMny;
    }

    public void setOutMny(String outMny) {
        this.outMny = outMny;
    }

    public String getDfzhName() {
        return dfzhName;
    }

    public void setDfzhName(String dfzhName) {
        this.dfzhName = dfzhName;
    }

    public String getGszhName() {
        return gszhName;
    }

    public void setGszhName(String gszhName) {
        this.gszhName = gszhName;
    }
}

==> ejc-bfyjerp-api-3.0.0-20250123.022604-122-sources.jar: com/ejianc/business/finance/vo/PayFlowVO.java <==
package com.ejianc.business.finance.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 出纳资金-出纳流水明细表
 * 
 * @author generator
 * 
 */
public class PayFlowVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date date; //日期
    private Integer parentOrgName; //区域
    private String payType; //收支类型
    private String onetypeName; //一级分类
    private String twoTypeName; //二级分类
    private String projectName; //项目名称
    private String memo; //摘要
    private BigDecimal inMny; //收入
    private BigDecimal outMny; //支出
    private String dfzhName; //对方账户
    private String gszhName; //公司账户

    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    public Integer getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(Integer parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public String getOnetypeName() {
        return onetypeName;
    }

    public void setOnetypeName(String onetypeName) {
        this.onetypeName = onetypeName;
    }

    public String getTwoTypeName() {
        return twoTypeName;
    }

    public void setTwoTypeName(String twoTypeName) {
        this.twoTypeName = twoTypeName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getInMny() {
        return inMny;
    }

    public void setInMny(BigDecimal inMny) {
        this.inMny = inMny;
    }

    public BigDecimal getOutMny() {
        return outMny;
    }

    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }

    public String getDfzhName() {
        return dfzhName;
    }

    public void setDfzhName(String dfzhName) {
        this.dfzhName = dfzhName;
    }

    public String getGszhName() {
        return gszhName;
    }

    public void setGszhName(String gszhName) {
        this.gszhName = gszhName;
    }
}
